spannertools.Spanner
====================

.. abjad-lineage:: abjad.tools.spannertools.Spanner.Spanner.Spanner

.. autoclass:: abjad.tools.spannertools.Spanner.Spanner.Spanner
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.set
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.start_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.storage_format
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.timespan
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Spanner.Spanner.Spanner.written_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.clear
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.pop_left
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__ge__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__gt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__le__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Spanner.Spanner.Spanner.__repr__
   :noindex:
